@@ -69,12 +69,9 @@ describe 'horizon' do
           "    'can_set_mount_point': True,",
           "    'can_set_password': False,",
           "    'enable_distributed_router': False,",
-          "    'enable_firewall': False,",
           "    'enable_ha_router': False,",
-          "    'enable_lb': False,",
           "    'enable_quotas': True,",
           "    'enable_security_group': True,",
-          "    'enable_vpn': False,",
           'API_RESULT_LIMIT = 1000',
           'DROPDOWN_MAX_ITEMS = 30',
           'TIME_ZONE = "UTC"',
@@ -118,8 +115,7 @@ describe 'horizon' do
           :hypervisor_options             => {'can_set_mount_point' => false, 'can_set_password' => true },
           :cinder_options                 => {'enable_backup' => true },
           :keystone_options               => {'name' => 'native', 'can_edit_user' => true, 'can_edit_group' => true, 'can_edit_project' => true, 'can_edit_domain' => false, 'can_edit_role' => false},
-          :neutron_options                => {'enable_lb' => true, 'enable_firewall' => true, 'enable_quotas' => false, 'enable_security_group' => false, 'enable_vpn' => true,
-                                            'enable_distributed_router' => false, 'enable_ha_router' => false, 'profile_support' => 'cisco',
+          :neutron_options                => {'enable_quotas' => false, 'enable_security_group' => false, 'enable_distributed_router' => false, 'enable_ha_router' => false,
                                             'supported_provider_types' => ['flat', 'vxlan'], 'supported_vnic_types' => ['*'], 'default_ipv4_subnet_pool_label' => 'None', },
           :instance_options               => {'disable_image' => true, 'disable_instance_snapshot' => true, 'disable_volume' => true, 'disable_volume_snapshot' => true, 'create_volume' => false },
           :file_upload_temp_dir           => '/var/spool/horizon',
@@ -142,6 +138,7 @@ describe 'horizon' do
           :create_image_defaults          => {'image_visibility' => 'private'},
           :password_retrieve              => true,
           :enable_secure_proxy_ssl_header => true,
+          :secure_proxy_addr_header       => 'HTTP_X_FORWARDED_FOR',
         })
       end
 
@@ -151,6 +148,7 @@ describe 'horizon' do
           "SITE_BRANDING = 'mysite'",
           "ALLOWED_HOSTS = ['some.host.tld', ]",
           "SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')",
+          "SECURE_PROXY_ADDR_HEADER = 'HTTP_X_FORWARDED_FOR'",
           'CSRF_COOKIE_SECURE = True',
           'SESSION_COOKIE_SECURE = True',
           'SESSION_COOKIE_HTTPONLY = True',
@@ -181,12 +179,8 @@ describe 'horizon' do
           "    'can_set_password': True,",
           "    'enable_backup': True,",
           "    'default_ipv4_subnet_pool_label': None,",
-          "    'enable_firewall': True,",
-          "    'enable_lb': True,",
           "    'enable_quotas': False,",
           "    'enable_security_group': False,",
-          "    'enable_vpn': True,",
-          "    'profile_support': 'cisco',",
           "    'supported_provider_types': ['flat', 'vxlan'],",
           "    'supported_vnic_types': ['*'],",
           'OPENSTACK_ENABLE_PASSWORD_RETRIEVE = True',
